@@ -139,6 +139,8 @@ cheese_thumb_view_thread_append_item (gpointer data)
   g_free (thumb_loc);
   g_free (uri);
 
+  gdk_threads_enter ();
+
   if (!pixbuf)
   {
     gchar  *escape = NULL;
@@ -161,8 +163,6 @@ cheese_thumb_view_thread_append_item (gpointer data)
     cheese_thumbnail_add_frame (&pixbuf);
   }
 
-  gdk_threads_enter ();
-
   gtk_list_store_set (priv->store, &iter,
                       THUMBNAIL_PIXBUF_COLUMN, pixbuf, -1);
 
@@ -192,7 +192,7 @@ cheese_thumb_view_append_item (CheeseThumbView *thumb_view, GFile *file)
 
   filename = g_file_get_path (file);
 
-  if (!(g_str_has_suffix (filename, PHOTO_NAME_SUFFIX)) && !(g_str_has_suffix (filename, VIDEO_NAME_SUFFIX)))
+  if (!(g_str_has_suffix (filename, CHEESE_PHOTO_NAME_SUFFIX)) && !(g_str_has_suffix (filename, CHEESE_VIDEO_NAME_SUFFIX)))
   {
     g_free (filename);
     return;
@@ -488,7 +488,7 @@ cheese_thumb_view_fill (CheeseThumbView *thumb_view)
   CheeseThumbViewPrivate *priv = CHEESE_THUMB_VIEW_GET_PRIVATE (thumb_view);
 
   GDir       *dir_videos, *dir_photos;
-  char       *path_videos, *path_photos;
+  const char *path_videos, *path_photos;
   const char *name;
   char       *filename;
   GFile      *file;
@@ -515,7 +515,7 @@ cheese_thumb_view_fill (CheeseThumbView *thumb_view)
     /* read videos from the vid directory */
     while ((name = g_dir_read_name (dir_videos)))
     {
-      if (!(g_str_has_suffix (name, VIDEO_NAME_SUFFIX)))
+      if (!(g_str_has_suffix (name, CHEESE_VIDEO_NAME_SUFFIX)))
         continue;
 
       filename = g_build_filename (path_videos, name, NULL);
@@ -533,7 +533,7 @@ cheese_thumb_view_fill (CheeseThumbView *thumb_view)
     /* read photos from the photo directory */
     while ((name = g_dir_read_name (dir_photos)))
     {
-      if (!(g_str_has_suffix (name, PHOTO_NAME_SUFFIX)))
+      if (!(g_str_has_suffix (name, CHEESE_PHOTO_NAME_SUFFIX)))
         continue;
 
       filename = g_build_filename (path_photos, name, NULL);
@@ -675,7 +675,7 @@ cheese_thumb_view_new ()
 }
 
 void
-cheese_thumb_view_start_monitoring_photo_path (CheeseThumbView *thumb_view, char *path_photos)
+cheese_thumb_view_start_monitoring_photo_path (CheeseThumbView *thumb_view, const char *path_photos)
 {
   CheeseThumbViewPrivate *priv = CHEESE_THUMB_VIEW_GET_PRIVATE (thumb_view);
 
@@ -694,7 +694,7 @@ cheese_thumb_view_start_monitoring_photo_path (CheeseThumbView *thumb_view, char
 }
 
 void
-cheese_thumb_view_start_monitoring_video_path (CheeseThumbView *thumb_view, char *path_videos)
+cheese_thumb_view_start_monitoring_video_path (CheeseThumbView *thumb_view, const char *path_videos)
 {
   CheeseThumbViewPrivate *priv = CHEESE_THUMB_VIEW_GET_PRIVATE (thumb_view);
 
